%bcond_with bootstrap

Name:           guava
Version:        32.1.3
Release:        %mkrel 1
Group:          Development/Java
Summary:        Google Core Libraries for Java
# Most of the code is under ASL 2.0
# Few classes are under CC0, grep for creativecommons
License:        Apache-2.0 AND CC0-1.0
URL:            https://github.com/google/guava
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://github.com/google/guava/archive/v%{version}/guava-%{version}.tar.gz

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local maven-openjdk21
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
%endif
BuildRequires:  jurand

%description
Guava is a suite of core and expanded libraries that include
utility classes, Google’s collections, io classes, and much
much more.
This project is a complete packaging of all the Guava libraries
into a single jar.  Individual portions of Guava can be used
by downloading the appropriate module and its dependencies.

%{?javadoc_package}

%package testlib
Summary:        The guava-testlib artifact

%description testlib
guava-testlib provides additional functionality for conveninent unit testing

%prep
%setup -q

find . -name '*.jar' -delete

%pom_remove_parent guava-bom

%pom_disable_module guava-gwt
%pom_disable_module guava-tests

%pom_xpath_inject pom:modules "<module>futures/failureaccess</module>"
%pom_xpath_inject pom:parent "<relativePath>../..</relativePath>" futures/failureaccess
%pom_xpath_set pom:parent/pom:version %{version}-jre futures/failureaccess

%pom_remove_plugin -r :animal-sniffer-maven-plugin
# Downloads JDK source for doc generation
%pom_remove_plugin :maven-dependency-plugin guava

%pom_remove_dep :caliper guava-tests

%mvn_package :guava-parent guava

# javadoc generation fails due to strict doclint in JDK 1.8.0_45
%pom_remove_plugin -r :maven-javadoc-plugin

%pom_remove_plugin -r :build-helper-maven-plugin

%pom_xpath_inject /pom:project/pom:build/pom:plugins/pom:plugin/pom:configuration/pom:instructions "<_nouses>true</_nouses>" guava/pom.xml

# missing error_prone_core artifact
%pom_xpath_remove pom:annotationProcessorPaths

%pom_remove_dep -r :error_prone_annotations
%pom_remove_dep -r :j2objc-annotations
%pom_remove_dep -r org.checkerframework:
%pom_remove_dep -r :listenablefuture

%java_remove_annotations guava guava-testlib -s \
  -p org[.]checkerframework[.] \
  -p com[.]google[.]common[.]annotations[.] \
  -p com[.]google[.]errorprone[.]annotations[.] \
  -p com[.]google[.]j2objc[.]annotations[.] \

%mvn_package "com.google.guava:failureaccess" guava

%mvn_package "com.google.guava:guava-bom" __noinstall

%build
# Tests fail on Koji due to insufficient memory,
# see https://bugzilla.redhat.com/show_bug.cgi?id=1332971
%mvn_build -s -f

%install
%mvn_install

%files -f .mfiles-guava
%doc CONTRIBUTORS README*
%license LICENSE

%files testlib -f .mfiles-guava-testlib




%changelog
* Sat May 25 2024 ns80 <ns80> 32.1.3-1.mga10
+ Revision: 2067654
- new version 32.1.3 for java 21

* Tue Apr 30 2024 ns80 <ns80> 32.0.1-1.mga10
+ Revision: 2061745
- new version 32.0.1 for CVE-2020-8908 and CVE-2023-2976 (mga#33071)

* Mon Jul 25 2022 neoclust <neoclust> 31.0.1-3.mga9
+ Revision: 1871026
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 31.0.1-2.mga9
+ Revision: 1870263
- Fix BR for bootstrap

* Wed Jun 08 2022 neoclust <neoclust> 31.0.1-1.mga9
+ Revision: 1863528
- New version 31.0.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Wed Dec 30 2020 neoclust <neoclust> 25.0-6.mga8
+ Revision: 1665809
- Add P0 to fix CVE-2020-8908 (mga#27965)

* Sun Aug 23 2020 neoclust <neoclust> 25.0-4.mga8
+ Revision: 1618168
- Drop unnecessary dependency on parent POM.

* Fri Feb 14 2020 umeabot <umeabot> 25.0-3.mga8
+ Revision: 1520858
- Mageia 8 Mass Rebuild
+ daviddavid <daviddavid>
- rebuild against fixed java stack
+ neoclust <neoclust>
- New version 25

* Wed Oct 10 2018 guillomovitch <guillomovitch> 20.0-1.mga7
+ Revision: 1319329
- new version 20.0

* Thu Oct 04 2018 guillomovitch <guillomovitch> 25.1-1.mga7
+ Revision: 1317335
- new version 25.1

* Sun Sep 23 2018 umeabot <umeabot> 18.0-10.mga7
+ Revision: 1298137
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 25.0-2.mga7
+ Revision: 1261441
- Mageia 7 Mass Rebuild

* Wed May 16 2018 daviddavid <daviddavid> 25.0-1.mga7
+ Revision: 1229770
+ rebuild (emptylog)

* Sun May 14 2017 neoclust <neoclust> 18.0-9.mga6
+ Revision: 1101109
- Allow conditional builds without testlib

* Wed Mar 02 2016 neoclust <neoclust> 18.0-6.mga6
+ Revision: 982458
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 18.0-5.mga6
+ Revision: 976273
- First rebuild of the java stack
- sync package guava with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Jul 13 2015 daviddavid <daviddavid> 18.0-1.mga6
+ Revision: 853554
- sync with fc23 (update to 18.0)
  * Remove maven-javadoc-plugin execution
  * Update upstream website URL
  * Add alias for com.google.guava:guava-jdk5
- fix Group
- fix owner of maven-poms dir

* Wed Oct 15 2014 umeabot <umeabot> 17.0-3.mga5
+ Revision: 743180
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 dmorgan <dmorgan> 17.0-1.mga5
+ Revision: 670245
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 dmorgan <dmorgan> 13.0-4.mga4
+ Revision: 484337
- Build with xmvn

* Tue Jul 30 2013 joequant <joequant> 13.0-3.mga4
+ Revision: 461159
- remove java-nodeps from buildrequires

* Sat Jan 12 2013 umeabot <umeabot> 13.0-2.mga3
+ Revision: 352942
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 09 2012 dmorgan <dmorgan> 13.0-1.mga3
+ Revision: 290821
- New version 13.0

* Mon Dec 12 2011 gil <gil> 09-1.mga2
+ Revision: 181044
- update to 09
  Obsoletes/Provides guava09
  added backward compatibility symlink
  maven build support

* Thu Jan 20 2011 dmorgan <dmorgan> 05-1.mga1
+ Revision: 25595
- Adapt to mageia
- imported package guava


* Wed Jul 14 2010 Hui wang <huwang@redhat.com> - 05-4
- Patch pom

* Fri Jun 18 2010 Hui Wang <huwang@redhat.com> - 05-3
- Fixed jar name in install section
- Removed spaces in description

* Thu Jun 17 2010 Hui Wang <huwang@redhat.com> - 05-2
- Fixed summary
- Fixed description
- Fixed creating symlink insturctions
- add depmap

* Thu Jun 10 2010 Hui Wang <huwang@redhat.com> - 05-1
- Initial version of the package